      SUBROUTINE REPP(NI,NJ,RIJ,RI,CORE)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION RI(22),CORE(4,2)
      COMMON /MULTIP/ DD(107),QQ(107),ADD(107,3)
      COMMON /CORE/ TORE(107)
      COMMON /NATORB/ NATORB(107)
C***********************************************************************
C
C  REPP CALCULATES THE TWO-ELECTRON REPULSION INTEGRALS AND THE
C       NUCLEAR ATTRACTION INTEGRALS.
C
C     ON INPUT RIJ     = INTERATOMIC DISTANCE
C              NI      = ATOM NUMBER OF FIRST ATOM
C              NJ      = ATOM NUMBER OF SECOND ATOM
C    (REF)     ADD     = ARRAY OF GAMMA, OR TWO-ELECTRON ONE-CENTER,
C                        INTEGRALS.
C    (REF)     TORE    = ARRAY OF NUCLEAR CHARGES OF THE ELEMENTS
C    (REF)     DD      = ARRAY OF DIPOLE CHARGE SEPARATIONS
C    (REF)     QQ      = ARRAY OF QUADRUPOLE CHARGE SEPARATIONS
C
C     THE COMMON BLOCKS ARE INITIALIZED IN BLOCK-DATA, AND NEVER CHANGED
C
C    ON OUTPUT RI      = ARRAY OF TWO-ELECTRON REPULSION INTEGRALS
C              CORE    = 4 X 2 ARRAY OF ELECTRON-CORE ATTRACTION
C                        INTEGRALS
C
C***********************************************************************
      R=RIJ/0.529167D00
      PP=2.0D00
      P2=4.0D00
      P3=8.0D00
      P4=16.0D00
C
C *** THIS ROUTINE COMPUTES THE TWO-CENTRE REPULSION INTEGRALS AND THE
C *** NUCLEAR ATTRACTION INTEGRALS.
C *** THE TWO-CENTRE REPULSION INTEGRALS (OVER LOCAL COORDINATES) ARE
C *** STORED AS FOLLOWS (WHERE P-SIGMA = O,  AND P-PI = P AND P* )
C     (SS/SS)=1,   (SO/SS)=2,   (OO/SS)=3,   (PP/SS)=4,   (SS/OS)=5,
C     (SO/SO)=6,   (SP/SP)=7,   (OO/SO)=8,   (PP/SO)=9,   (PO/SP)=10,
C     (SS/OO)=11,  (SS/PP)=12,  (SO/OO)=13,  (SO/PP)=14,  (SP/OP)=15,
C     (OO/OO)=16,  (PP/OO)=17,  (OO/PP)=18,  (PP/PP)=19,  (PO/PO)=20,
C     (PP/P*P*)=21,   (P*P/P*P)=22.
C *** THE STORAGE OF THE NUCLEAR ATTRACTION INTEGRALS  CORE(KL/IJ) IS
C     (SS/)=1,   (SO/)=2,   (OO/)=3,   (PP/)=4
C     WHERE IJ=1 IF THE ORBITALS CENTRED ON ATOM I,  =2 IF ON ATOM J.
C *** NI AND NJ ARE THE ATOMIC NUMBERS OF THE TWO ELEMENTS.
C
      DO 10 I=1,22
   10 RI(I)=0.0D00
      DO 20 I=1,4
         CORE(I,1)=0.0D00
   20 CORE(I,2)=0.0D00
C
C     ATOMIC UNITS ARE USED IN THE CALCULATION
C     DEFINE CHARGE SEPARATIONS.
C
      DA=DD(NI)
      DB=DD(NJ)
      QA=QQ(NI)
      QB=QQ(NJ)
      TD = 2.D00
      OD = 1.D00
      FD = 4.D00
C
C     HYDROGEN - HYDROGEN
C
      AEE=0.25D00*(OD/ADD(NI,1)+OD/ADD(NJ,1))**2
      EE=OD/SQRT(R**2+AEE)
      RI(1)=EE*27.21D00
      CORE(1,1)=TORE(NJ)*RI(1)
      CORE(1,2)=TORE(NI)*RI(1)
      IF (NATORB(NI).LT.3.AND.NATORB(NJ).LT.3) RETURN
      IF (NATORB(NI).LT.3) GO TO 30
C
C     HEAVY ATOM - HYDROGEN
C
      ADE=0.25D00*(OD/ADD(NI,2)+OD/ADD(NJ,1))**2
      AQE=0.25D00*(OD/ADD(NI,3)+OD/ADD(NJ,1))**2
      DZE=-OD/SQRT((R+DA)**2+ADE)+OD/SQRT((R-DA)**2+ADE)
      QZZE=OD/SQRT((R-TD*QA)**2+AQE)-TD/SQRT(R**2+AQE)+OD/
     1SQRT((R+TD*QA)**2+AQE)
      QXXE=TD/SQRT(R**2+FD*QA**2+AQE)-TD/SQRT(R**2+AQE)
      DZE=DZE/PP
      QXXE=QXXE/P2
      QZZE=QZZE/P2
      RI(2)=-DZE
      RI(3)=EE+QZZE
      RI(4)=EE+QXXE
      IF (NATORB(NJ).LT.3) GO TO 40
C
C     HYDROGEN - HEAVY ATOM
C
   30 CONTINUE
      AED=0.25D00*(OD/ADD(NI,1)+OD/ADD(NJ,2))**2
      AEQ=0.25D00*(OD/ADD(NI,1)+OD/ADD(NJ,3))**2
      EDZ=-OD/SQRT((R-DB)**2+AED)+OD/SQRT((R+DB)**2+AED)
      EQZZ=OD/SQRT((R-TD*QB)**2+AEQ)-TD/SQRT(R**2+AEQ)+OD/
     1SQRT((R+TD*QB)**2+AEQ)
      EQXX=TD/SQRT(R**2+FD*QB**2+AEQ)-TD/SQRT(R**2+AEQ)
      EDZ=EDZ/PP
      EQXX=EQXX/P2
      EQZZ=EQZZ/P2
      RI(5)=-EDZ
      RI(11)=EE+EQZZ
      RI(12)=EE+EQXX
      IF (NATORB(NI).LT.3) GO TO 40
C
C     HEAVY ATOM - HEAVY ATOM
C     CAUTION. ADD REPLACES ADD(1,1) IN /MULTIP/ AND MUST BE RESET.
C
      ADD(1,1)=0.25D00*(OD/ADD(NI,2)+OD/ADD(NJ,2))**2
      ADQ=0.25D00*(OD/ADD(NI,2)+OD/ADD(NJ,3))**2
      AQD=0.25D00*(OD/ADD(NI,3)+OD/ADD(NJ,2))**2
      AQQ=0.25D00*(OD/ADD(NI,3)+OD/ADD(NJ,3))**2
      DXDX=TD/SQRT(R**2+(DA-DB)**2+ADD(1,1))
     1-TD/SQRT(R**2+(DA+DB)**2+ADD(1,1))
      DZDZ=OD/SQRT((R+DA-DB)**2+ADD(1,1))
     1+OD/SQRT((R-DA+DB)**2+ADD(1,1))-OD/SQRT((
     2R-DA-DB)**2+ADD(1,1))-OD/SQRT((R+DA+DB)**2+ADD(1,1))
      DZQXX=-TD/SQRT((R+DA)**2+FD*QB**2+ADQ)+TD/SQRT((R-DA)**2
     1+FD*QB**2+
     2ADQ)+TD/SQRT((R+DA)**2+ADQ)-TD/SQRT((R-DA)**2+ADQ)
      QXXDZ=-TD/SQRT((R-DB)**2+FD*QA**2+AQD)+TD/SQRT((R+DB)**2
     1+FD*QA**2+
     2AQD)+TD/SQRT((R-DB)**2+AQD)-TD/SQRT((R+DB)**2+AQD)
      DZQZZ=-OD/SQRT((R+DA-TD*QB)**2+ADQ)+OD/SQRT((R-DA-TD*
     1QB)**2+ADQ)-OD/SQRT((R+DA+TD*QB)**2+ADQ)+OD/SQRT((R-DA+TD*QB)
     2**2+ADQ)-TD/SQRT((R-DA)**2+ADQ)+TD/SQRT((R+DA)**2+ADQ)
      QZZDZ=-OD/SQRT((R+TD*QA-DB)**2+AQD)+OD/SQRT((R+TD*QA+
     1DB)**2+AQD)-OD/SQRT((R-TD*QA-DB)**2+AQD)+OD/SQRT((R-2.D
     200*QA+DB)**2+AQD)+TD/SQRT((R-DB)**2+AQD)-TD/SQRT((R+DB)**2
     3+AQD)
      QXXQXX=TD/SQRT(R**2+FD*(QA-QB)**2+AQQ)+TD/SQRT(R**2+FD*(QA+QB)**2+
     1AQQ)-FD/SQRT(R**2+FD*QA**2+AQQ)-FD/SQRT(R**2+FD*QB**2+AQQ)+FD/SQRT
     2(R**2+AQQ)
      QXXQYY=FD/SQRT(R**2+FD*QA**2+FD*QB**2+AQQ)-FD/SQRT(R**2+FD*QA**2+A
     1QQ)-FD/SQRT(R**2+FD*QB**2+AQQ)+FD/SQRT(R**2+AQQ)
      QXXQZZ=TD/SQRT((R-TD*QB)**2+FD*QA**2+AQQ)+TD/SQRT((R+TD*QB)**2+FD*
     1QA**2+AQQ)-TD/SQRT((R-TD*QB)**2+AQQ)-TD/SQRT((R+TD*QB)**2+AQQ)-FD/
     2SQRT(R**2+FD*QA**2+AQQ)+FD/SQRT(R**2+AQQ)
      QZZQXX=TD/SQRT((R+TD*QA)**2+FD*QB**2+AQQ)+TD/SQRT((R-TD*QA)**2+FD*
     1QB**2+AQQ)-TD/SQRT((R+TD*QA)**2+AQQ)-TD/SQRT((R-TD*QA)**2+AQQ)-FD/
     2SQRT(R**2+FD*QB**2+AQQ)+FD/SQRT(R**2+AQQ)
      QZZQZZ=OD/SQRT((R+TD*QA-TD*QB)**2+AQQ)+OD/SQRT((R+TD*QA+TD*QB)**2+
     1AQQ)+OD/SQRT((R-TD*QA-TD*QB)**2+AQQ)+OD/SQRT((R-TD*QA+TD*QB)**2+AQ
     2Q)-TD/SQRT((R-TD*QA)**2+AQQ)-TD/SQRT((R+TD*QA)**2+AQQ)-TD/SQRT((R-
     3TD*QB)**2+AQQ)-TD/SQRT((R+TD*QB)**2+AQQ)+FD/SQRT(R**2+AQQ)
      DXQXZ=-TD/SQRT((R-QB)**2+(DA-QB)**2+ADQ)+TD/SQRT((R+QB)**2+(DA-QB)
     1**2+ADQ)+TD/SQRT((R-QB)**2+(DA+QB)**2+ADQ)-TD/SQRT((R+QB)**2+(DA+Q
     2B)**2+ADQ)
      QXZDX=-TD/SQRT((R+QA)**2+(QA-DB)**2+AQD)+TD/SQRT((R-QA)**2+(QA-DB)
     1**2+AQD)+TD/SQRT((R+QA)**2+(QA+DB)**2+AQD)-TD/SQRT((R-QA)**2+(QA+D
     2B)**2+AQD)
      QXYQXY=FD/SQRT(R**2+TD*(QA-QB)**2+AQQ)+FD/SQRT(R**2+TD*(QA+QB)**2+
     1AQQ)-8.D00/SQRT(R**2+TD*(QA**2+QB**2)+AQQ)
      QXZQXZ=TD/SQRT((R+QA-QB)**2+(QA-QB)**2+AQQ)-TD/SQRT((R+QA+QB)**2+(
     1QA-QB)**2+AQQ)-TD/SQRT((R-QA-QB)**2+(QA-QB)**2+AQQ)+TD/SQRT((R-QA+
     2QB)**2+(QA-QB)**2+AQQ)-TD/SQRT((R+QA-QB)**2+(QA+QB)**2+AQQ)+TD/SQR
     3T((R+QA+QB)**2+(QA+QB)**2+AQQ)+TD/SQRT((R-QA-QB)**2+(QA+QB)**2+AQQ
     4)-TD/SQRT((R-QA+QB)**2+(QA+QB)**2+AQQ)
      DXDX=DXDX/P2
      DZDZ=DZDZ/P2
      DZQXX=DZQXX/P3
      QXXDZ=QXXDZ/P3
      DZQZZ=DZQZZ/P3
      QZZDZ=QZZDZ/P3
      DXQXZ=DXQXZ/P3
      QXZDX=QXZDX/P3
      QXXQXX=QXXQXX/P4
      QXXQYY=QXXQYY/P4
      QXXQZZ=QXXQZZ/P4
      QZZQXX=QZZQXX/P4
      QZZQZZ=QZZQZZ/P4
      QXZQXZ=QXZQXZ/P4
      QXYQXY=QXYQXY/P4
      RI(6)=DZDZ
      RI(7)=DXDX
      RI(8)=-EDZ-QZZDZ
      RI(9)=-EDZ-QXXDZ
      RI(10)=-QXZDX
      RI(13)=-DZE-DZQZZ
      RI(14)=-DZE-DZQXX
      RI(15)=-DXQXZ
      RI(16)=EE+EQZZ+QZZE+QZZQZZ
      RI(17)=EE+EQZZ+QXXE+QXXQZZ
      RI(18)=EE+EQXX+QZZE+QZZQXX
      RI(19)=EE+EQXX+QXXE+QXXQXX
      RI(20)=QXZQXZ
      RI(21)=EE+EQXX+QXXE+QXXQYY
      RI(22)=0.5D0*(QXXQXX-QXXQYY)
      ADD(1,1)=ADD(1,2)
   40 CONTINUE
C
C     CONVERT INTO EV.
C
      DO 50 I=2,22
   50 RI(I)=RI(I)*27.21D00
C
C     CALCULATE CORE-ELECTRON ATTRACTIONS.
C
      CORE(2,1)=TORE(NJ)*RI(2)
      CORE(3,1)=TORE(NJ)*RI(3)
      CORE(4,1)=TORE(NJ)*RI(4)
      CORE(2,2)=TORE(NI)*RI(5)
      CORE(3,2)=TORE(NI)*RI(11)
      CORE(4,2)=TORE(NI)*RI(12)
      RETURN
C
      END
